@@ -4,6 +4,7 @@ lalrpop_mod!(#[allow(clippy::all, dead_code, unused_imports)] pub aidl);
 
 #[cfg(test)]
 mod tests {
+    use crate::diagnostic::DiagnosticKind;
     use crate::rules;
     use anyhow::Result;
 
@@ -17,10 +18,11 @@ mod tests {
             let mut diagnostics = Vec::new();
             let lookup = lookup($input);
             let res = $parser.parse(&lookup, &mut diagnostics, $input)?;
-            //println!("BW - diagnostics: {:?}", diagnostics);
             ::insta::assert_ron_snapshot!(res, {
                 ".**.symbol_range" => "...",
                 ".**.full_range" => "...",
+                ".**.value_range" => "...",
+                ".**.oneway_range" => "...",
             });
             assert_eq!(diagnostics, &[]);
         };
@@ -28,10 +30,11 @@ mod tests {
         ($input:ident, $parser:expr, $diag:expr) => {
             let lookup = lookup($input);
             let res = $parser.parse(&lookup, $diag, $input)?;
-            //println!("BW - diagnostics: {:?}", $diag);
             ::insta::assert_ron_snapshot!(res, {
                 ".**.symbol_range" => "...",
                 ".**.full_range" => "...",
+                ".**.value_range" => "...",
+                ".**.oneway_range" => "...",
             });
         };
     }
@@ -82,7 +85,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid item - Unrecognized token `oops_interface`\nExpected one of ANNOTATION, ENUM, IMPORT or PARCELABLE",
+            message: "Invalid item - Unrecognized token `oops_interface`\nExpected one of ANNOTATION, ENUM, IMPORT, INTERFACE or PARCELABLE",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -117,6 +120,38 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_declared_parcelable() -> Result<()> {
+        let mut diagnostics = Vec::new();
+
+        let input = "parcelable X;";
+        assert_parser!(
+            input,
+            rules::aidl::DeclaredParcelableParser::new(),
+            &mut diagnostics
+        );
+        let input = "parcelable any.pkg.Y;";
+        assert_parser!(
+            input,
+            rules::aidl::DeclaredParcelableParser::new(),
+            &mut diagnostics
+        );
+        let input = "@Annotation1 @Annotation2\nparcelable any.pkg.Y;";
+        assert_parser!(
+            input,
+            rules::aidl::DeclaredParcelableParser::new(),
+            &mut diagnostics
+        );
+
+        // Warning generated because it is recommended to define parcelables in AIDL
+        assert_eq!(diagnostics.len(), 3);
+        assert_eq!(diagnostics[0].kind, DiagnosticKind::Warning);
+        assert_eq!(diagnostics[1].kind, DiagnosticKind::Warning);
+        assert_eq!(diagnostics[2].kind, DiagnosticKind::Warning);
+
+        Ok(())
+    }
+
     #[test]
     fn test_interface() -> Result<()> {
         let input = r#"interface Potato {
@@ -138,6 +173,14 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_oneway_interface() -> Result<()> {
+        let input = r#"oneway interface OneWayInterface {}"#;
+        assert_parser!(input, rules::aidl::InterfaceParser::new());
+
+        Ok(())
+    }
+
     #[test]
     fn test_interface_with_annotation() -> Result<()> {
         let input = r#"@InterfaceAnnotation1
